        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
}
