        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 27 <br>1,3,5,7,8,9,11,13,15,16,18,19,20,21,22,24,25,26,28,30,33,35,39,40,41,46,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 14 <strong>control</strong><br>0,2,6,10,14,27,34,36,38,42,45,47,48,50';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260617 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>4,12,17,23,29,31,32,37,43,44';}
}
